#!/bin/sh -ef

PROG="${0##*/}"

. shell-args

show_help()
{
        cat <<EOF
Usage: $PROG [options] --remote-node=FQDN|--autojoin=(none|other|any)

Options:
  --local-node=FQDN                 Hostname of local node (must be in /etc/hosts or DNS);
  --remote-node=FQDN                Hostname of remote node (must be in /etc/hosts or DNS);
  --autojoin=(none|other|any)       Enables nodes to join automatically;
  --ucast-ip=IPv4                   Ip address for sending unicast messages;
  --ucast-interface=IF              Network interface for sending unicast messages (e.g. eth0);
  --mcast-settings=
    "dev group port ttl loop"       Settings for multicast messages;
  --bcast-interfaces=(auto|"IF [IF ...]")
                                    Space separated list of broadcast interfaces;
  --serial=DEV                      Serial device for node communications;
  --gateway=IPv4                    Ip address of network gateway;
  --file=PATH                       File for writing config;
  --help, -h                        Show this text and exit.
EOF
        exit
}

[ "$#" -ge 1 ] || show_help

local_node=`uname -n`
auto_failback=legacy
file=/dev/stdout

TEMP=`getopt -n $PROG -o h -l local-node:,remote-node:,autojoin:,ucast-interface:,ucast-ip:,mcast-settings:,bcast-interfaces:,serial:,gateway:,file:,help -- "$@"` ||
	show_help

eval set -- "$TEMP"

while :; do
        case "$1" in
                --local-node)
			shift
                        local_node="$1"
                        ;;
                --remote-node)
			shift
                        remote_node="$1"
                        ;;
                --autojoin)
			shift
                        autojoin="$1"
                        ;;
                --ucast-interface)
			shift
                        ucast_interface="$1"
                        ;;
                --ucast-ip)
			shift
                        ucast_ip="$1"
                        ;;
                --mcast-settings)
			shift
                        mcast_settings="$1"
                        ;;
                --bcast-interfaces)
			shift
                        bcast_interfaces="$1"
                        ;;
                --serial)
			shift
                        serial="$1"
                        ;;
                --gateway)
			shift
                        gateway="$1"
                        ;;
                --file)
			shift
                        file="$1"
                        ;;
		--help|-h)
			show_help
			;;
                --) shift; break
                        ;;
        esac
        shift
done

if [ -z "$remote_node" -a -z "$autojoin" ]; then
    show_usage 'Insufficient arguments, supply --remote-node or --autojoin'
fi

if [ -z "$ucast_interface" -a -n "$ucast_ip" ]; then
    ucast_interface=`/sbin/ip r get "$ucast_ip" | egrep -o "dev [^ ]+" | cut -d ' ' -f 2`
fi

if [ -n "$ucast_interface" -a -z "$ucast_ip" ]; then
    show_usage 'Insufficient arguments, missing --ucast-ip for using unicast messages'
fi

if [ -z "$ucast_ip" -a -z "$mcast_settings" -a -z "$bcast_interfaces" -a -z "$serial" ]; then
    show_usage 'Insufficient arguments, use at least one of --ucast-ip|--mcast-settings|--bcast-interfaces|--serial'
fi

if [ -z "$gateway" ]; then
    gateway=`/sbin/ip r | grep ^default | cut -d " " -f 3`
fi

if [ x"$bcast_interfaces" = x"auto" ]; then
    bcast_interfaces=`/sbin/ip -o link show up | grep -w BROADCAST | grep "link/ether" | grep -v -w NO-CARRIER | cut -d ':' -f 2`
fi


echo "node $local_node $remote_node" > "$file"
echo "crm on" >> "$file"
if [ -n "$autojoin" ]; then
    echo "autojoin $autojoin" >> "$file"
fi
echo "ping $gateway" >> "$file"
if [ -n "$ucast_ip" ]; then
    echo "ucast $ucast_interface $ucast_ip" >> "$file"
fi
if [ -n "$mcast_settings" ]; then
    echo "mcast $mcast_settings" >> "$file"
fi
if [ -n "$bcast_interfaces" ]; then
    echo -n "bcast" >> "$file"
    for i in $bcast_interfaces; do
	echo -n " $i" >> "$file"
    done
    echo >> "$file"
fi
if [ -n "$serial" ]; then
    echo "serial $serial" >> "$file"
fi
