#!/bin/sh -ef

PROG="${0##*/}"

. shell-args

show_help()
{
        cat <<EOF
Usage: $PROG [options] --param=STRING

Options:
  --file=PATH                       File for reading heartbeat config from;
  --param=(local-node|...)          One of heartbeat config param, 
                                    see configure-heartbeat-config.sh help;
  --help, -h                        Show this text and exit.
EOF
        exit
}

[ "$#" -ge 1 ] || show_help

local_node=`uname -n`
auto_failback=on
gateway=`/sbin/ip r | grep ^default | cut -d " " -f 3`
file=/etc/ha.d/ha.cf

TEMP=`getopt -n $PROG -o h -l file:,param:,help -- "$@"` ||
	show_help

eval set -- "$TEMP"

while :; do
        case "$1" in
                --file)
			shift
                        file="$1"
                        ;;
                --param)
			shift
			if [ -n "$param" ]; then
			    show_usage 'Only one --param allowed'
			    break
			fi
                        param="$1"
                        ;;
		--help|-h)
			show_help
			;;
                --) shift; break
                        ;;
        esac
        shift
done

if [ -z "$param" ]; then
    show_usage 'Insufficient arguments, missing --param'
fi

test -f "$file" || echo "Warning: can't read config file \"$file\"" >&2

if [ -f "$file" ]; then
    for n in `grep "^node" "$file" | cut -d " " -f 2-`; do
	if [ -z "$first_node" ]; then
    	    first_node="$n"
	elif [ -z "$second_node" ]; then
    	    second_node="$n"
	else
    	    echo "Warning: only two nodes supported" >&2
	fi
    done
    if [ x"$first_node" = x"$local_node" ]; then
	remote_node="$second_node"
    elif [ x"$second_node" = x"$local_node" ]; then
	remote_node="$first_node"
    else
	# FIXME: check for blank first_node
	local_node="$first_node"
	remote_node="$second_node"
    fi
fi

echo_auto_failback()
{
    if [ -f "$file" ]; then
	grep "^auto_failback" "$file" | tail -n 1 | cut -s -d " " -f 2
    else
	echo legacy
    fi
}

echo_ucast_interface()
{
    if [ -f "$file" ]; then
	grep "^ucast" "$file" | tail -n 1 | cut -s -d " " -f 2
    else
	echo ""
    fi
}

echo_ucast_ip()
{
    if [ -f "$file" ]; then
	grep "^ucast" "$file" | tail -n 1 | cut -s -d " " -f 3
    else
	echo ""
    fi
}

echo_bcast_interfaces()
{
    if [ -f "$file" ]; then
	grep "^bcast" "$file" | tail -n 1 | cut -s -d " " -f 2-
    else
	echo ""
    fi
}

echo_mcast_settings()
{
    if [ -f "$file" ]; then
	grep "^mcast" "$file" | tail -n 1 | cut -s -d " " -f 2-
    else
	echo ""
    fi
}

echo_serial()
{
    if [ -f "$file" ]; then
	grep "^serial" "$file" | tail -n 1 | cut -s -d " " -f 2
    else
	echo ""
    fi
}

echo_gateway()
{
    if [ -f "$file" ]; then
	grep "^ping" "$file" | tail -n 1 | cut -s -d " " -f 2
    else
	echo ""
    fi
}

case "$param" in
	local-node)
	    echo "$local_node"
	    break
	    ;;
	remote-node)
	    echo "$remote_node"
	    break
	    ;;
	auto-failback)
	    echo_auto_failback
	    break
	    ;;
	ucast-interface)
	    echo_ucast_interface
	    break
	    ;;
	ucast-ip)
	    echo_ucast_ip
	    break
	    ;;
	bcast-interfaces)
	    echo_bcast_interfaces
	    break
	    ;;
	mcast-settings)
	    echo_mcast_settings
	    break
	    ;;
	serial)
	    echo_serial
	    break
	    ;;
	gateway)
	    echo_gateway
	    break
	    ;;
	*)
	    show_usage 'Unknown config param, see configure-heartbeat-config.sh help'
esac

exit 0
